{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return [\n    {\n      \"class\": \"Directory\",\n      \"basename\": inputs.index_base_name,\n      \"listing\": [],\n      \"writable\": true}\n  ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bowtie:v1.2.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--bmax"
                    },
                    "doc": "max bucket sz for blockwise suffix-array builder\n",
                    "id": "#bowtie-build.cwl/bmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--bmaxdivn"
                    },
                    "doc": "max bucket sz as divisor of ref len (default: 4)\n",
                    "id": "#bowtie-build.cwl/bmaxdivn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--color"
                    },
                    "doc": "build a colorspace index\n",
                    "id": "#bowtie-build.cwl/color"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--dcv"
                    },
                    "doc": "diff-cover period for blockwise (default: 1024)\n",
                    "id": "#bowtie-build.cwl/dcv"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": 25
                    },
                    "doc": "comma-separated list of files with ref sequences\n",
                    "id": "#bowtie-build.cwl/fasta_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--large-index"
                    },
                    "doc": "force generated index to be 'large', even if ref has fewer than 4 billion nucleotides\n",
                    "id": "#bowtie-build.cwl/force_large_index"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--ftabchars"
                    },
                    "doc": "# of chars consumed in initial lookup (default: 10)\n",
                    "id": "#bowtie-build.cwl/ftabchars"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 26,
                        "valueFrom": "$(\"./\"+self+\"/\"+self)"
                    },
                    "doc": "write Ebwt data to files with this dir/basename\n",
                    "id": "#bowtie-build.cwl/index_base_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--justref"
                    },
                    "doc": "just build .3/.4 index files\n",
                    "id": "#bowtie-build.cwl/justref"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--noauto"
                    },
                    "doc": "disable automatic -p/--bmax/--dcv memory-fitting\n",
                    "id": "#bowtie-build.cwl/noauto"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--nodc"
                    },
                    "doc": "disable diff-cover (algorithm becomes quadratic)\n",
                    "id": "#bowtie-build.cwl/nodc"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--noref"
                    },
                    "doc": "don't build .3/.4 index files\n",
                    "id": "#bowtie-build.cwl/noref"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--ntoa"
                    },
                    "doc": "convert Ns in reference to As\n",
                    "id": "#bowtie-build.cwl/ntoa"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--offrate"
                    },
                    "doc": "SA is sampled every 2^<int> BWT chars (default: 5)\n",
                    "id": "#bowtie-build.cwl/offrate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--packed"
                    },
                    "doc": "use packed strings internally; slower, less memory\n",
                    "id": "#bowtie-build.cwl/packed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 17,
                        "prefix": "--quiet"
                    },
                    "doc": "verbose output (for debugging)\n",
                    "id": "#bowtie-build.cwl/quiet"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 16,
                        "prefix": "--seed"
                    },
                    "doc": "seed for random number generator\n",
                    "id": "#bowtie-build.cwl/seed"
                }
            ],
            "baseCommand": [
                "bowtie-build"
            ],
            "stderr": "bowtie_stderr.log",
            "stdout": "bowtie_stdout.log",
            "doc": "Tool runs bowtie-build\nNot supported parameters:\n  -c  -  reference sequences given on cmd line (as <seq_in>)\n",
            "id": "#bowtie-build.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bowtie-metadata.yaml",
                "http://schema.org/name": "bowtie2",
                "http://schema.org/about": "Bowtie is an ultrafast, memory-efficient short read aligner. It aligns short DNA sequences (reads)\nto the human genome at a rate of over 25 million 35-bp reads per hour. Bowtie indexes the genome\nwith a Burrows-Wheeler index to keep its memory footprint small: typically about 2.2 GB for\nthe human genome (2.9 GB for paired-end).\n",
                "http://schema.org/url": "http://bowtie-bio.sourceforge.net/index.shtml",
                "http://schema.org/codeRepository": "https://github.com/BenLangmead/bowtie",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.2.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bowtie-metadata.yaml/10.1186/gb-2009-10-3-r25",
                        "datePublished": "04 March 2009",
                        "http://schema.org/name": "Ultrafast and memory-efficient alignment of short DNA sequences to the human genome",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ben Langmead"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Steven L Salzberg"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Cole Trapnell"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Mihai Pop"
                            }
                        ],
                        "http://schema.org/url": "https://genomebiology.biomedcentral.com/articles/10.1186/gb-2009-10-3-r25"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/BenLangmead/bowtie/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Johns Hopkins University",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ben Langmead",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bowtie-build",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bowtie-build.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: bowtie-build [options]* <reference_in> <ebwt_outfile_base>\n    reference_in            comma-separated list of files with ref sequences\n    ebwt_outfile_base       write Ebwt data to files with this dir/basename\nOptions:\n    -f                      reference files are Fasta (default)\n    -c                      reference sequences given on cmd line (as <seq_in>)\n    --large-index           force generated index to be 'large', even if ref\n                            has fewer than 4 billion nucleotides\n    -C/--color              build a colorspace index\n    -a/--noauto             disable automatic -p/--bmax/--dcv memory-fitting\n    -p/--packed             use packed strings internally; slower, uses less mem\n    --bmax <int>            max bucket sz for blockwise suffix-array builder\n    --bmaxdivn <int>        max bucket sz as divisor of ref len (default: 4)\n    --dcv <int>             diff-cover period for blockwise (default: 1024)\n    --nodc                  disable diff-cover (algorithm becomes quadratic)\n    -r/--noref              don't build .3/.4.ebwt (packed reference) portion\n    -3/--justref            just build .3/.4.ebwt (packed reference) portion\n    -o/--offrate <int>      SA is sampled every 2^offRate BWT chars (default: 5)\n    -t/--ftabchars <int>    # of chars consumed in initial lookup (default: 10)\n    --ntoa                  convert Ns in reference to As\n    --seed <int>            seed for random number generator\n    -q/--quiet              verbose output (for debugging)\n    -h/--help               print detailed description of tool and its options\n    --usage                 print this usage message\n    --version               print version information and quit\n",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.index_base_name)"
                    },
                    "id": "#bowtie-build.cwl/indices_folder"
                },
                {
                    "type": "File",
                    "id": "#bowtie-build.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "bowtie_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#bowtie-build.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "bowtie_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "sd:metadata": [
                "../metadata/indices-header.cwl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome FASTA file",
                    "doc": "Reference genome FASTA file. Includes all chromosomes",
                    "id": "#main/fasta_file"
                },
                {
                    "type": "string",
                    "label": "Genome type",
                    "doc": "Genome type, such as mm10, hg19, hg38, etc",
                    "id": "#main/genome"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "label": "Bowtie indices",
                    "doc": "Bowtie generated indices folder",
                    "outputSource": "#main/bowtie_build/indices_folder",
                    "id": "#main/indices_folder"
                },
                {
                    "type": "File",
                    "label": "Bowtie stderr log",
                    "doc": "Bowtie generated stderr log",
                    "outputSource": "#main/bowtie_build/stderr_log",
                    "id": "#main/stderr_log"
                },
                {
                    "type": "File",
                    "label": "Bowtie stdout log",
                    "doc": "Bowtie generated stdout log",
                    "outputSource": "#main/bowtie_build/stdout_log",
                    "id": "#main/stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#bowtie-build.cwl",
                    "in": [
                        {
                            "source": "#main/fasta_file",
                            "id": "#main/bowtie_build/fasta_file"
                        },
                        {
                            "source": "#main/genome",
                            "id": "#main/bowtie_build/index_base_name"
                        }
                    ],
                    "out": [
                        "#main/bowtie_build/indices_folder",
                        "#main/bowtie_build/stdout_log",
                        "#main/bowtie_build/stderr_log"
                    ],
                    "id": "#main/bowtie_build"
                }
            ],
            "label": "Build Bowtie indices",
            "doc": "Workflow runs [Bowtie](http://bowtie-bio.sourceforge.net/tutorial.shtml) v1.2.0 (12/30/2016) to build indices for reference\ngenome provided in a single FASTA file as fasta_file input. Generated indices are saved in a folder with the name that\ncorresponds to the input genome",
            "id": "#main",
            "http://schema.org/name": "Build Bowtie indices",
            "http://schema.org/alternateName": "Build Bowtie indices",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/dummy/bowtie-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
